theme property
ThemeData
get
theme
If you need reactive changes, do not use OneContext().theme
Use Theme.of(context) instead.
Implementation
ThemeData get theme => Theme.of(context!);
If you need reactive changes, do not use OneContext().theme
Use Theme.of(context) instead.
ThemeData get theme => Theme.of(context!);